# assertions-for-automated-testing #
`Gives us opportunity to do logical assertions with python`

# how to use
```python
from zzassertions.assertions import *

assertEquals(1, 1)
assertNotEquals(1, 2)
assertTrue(True)
assertFalse(False)